@@ -1,5 +1,7 @@
 #ifndef NSTD_ALLOC_H_INCLUDED
 #define NSTD_ALLOC_H_INCLUDED
 #include "alloc/alloc.h"
+#include "alloc/allocator.h"
 #include "alloc/heap.h"
+#include "nstd.h"
 #endif
