@@ -7,9 +7,9 @@
 typedef enum
 {
     /// A mouse button is/was released.
-    NSTD_MOUSE_BUTTON_RELEASED,
+    NSTD_MOUSE_BUTTON_STATE_RELEASED,
     /// A mouse button is/was pressed.
-    NSTD_MOUSE_BUTTON_PRESSED
+    NSTD_MOUSE_BUTTON_STATE_PRESSED
 } NSTDMouseButtonState;
 
 /// Represents a mouse button.
